Runtime

Struct Runtime 

pub struct Runtime { /* private fields */ }
An auto splitter runtime that allows using an auto splitter provided as a WebAssembly module to control a timer.

Implementations

Source

impl Runtime

pub fn new(timer: SharedTimer) -> Self

Starts the runtime. Doesn’t actually load an auto splitter until load_script is called.

pub async fn load_script(&self, script: PathBuf) -> Result<(), Error>

Attempts to load a wasm file containing an auto splitter module. This call will block until the auto splitter has either loaded successfully or failed.

pub fn load_script_blocking(&self, script: PathBuf) -> Result<(), Error>

Attempts to load a wasm file containing an auto splitter module. This call will block until the auto splitter has either loaded successfully or failed.

pub async fn unload_script(&self) -> Result<(), Error>

Unloads the current auto splitter. This will not return an error if there isn’t currently an auto splitter loaded, only if the runtime thread stops unexpectedly.

pub fn unload_script_blocking(&self) -> Result<(), Error>

Unloads the current auto splitter. This will not return an error if there isn’t currently an auto splitter loaded, only if the runtime thread stops unexpectedly.