pub struct Settings {
pub background: Gradient,
pub comparison_override: Option<String>,
pub display_two_rows: bool,
pub label_color: Option<Color>,
pub value_color: Option<Color>,
pub accuracy: Accuracy,
}Expand description
The Settings for this component.
Fields
background: GradientThe background shown behind the component.
comparison_override: Option<String>The comparison chosen. Uses the Timer’s current comparison if set to
None.
display_two_rows: boolSpecifies whether to display the name of the component and its value in two separate rows.
label_color: Option<Color>The color of the label. If None is specified, the color is taken from
the layout.
value_color: Option<Color>The color of the value. If None is specified, the color is taken from
the layout.
accuracy: AccuracyThe accuracy of the time shown.