State

Struct State 

pub struct State {
Show 14 fields pub points: Vec<Point>, pub horizontal_grid_lines: Vec<f32>, pub vertical_grid_lines: Vec<f32>, pub middle: f32, pub is_live_delta_active: bool, pub is_flipped: bool, pub top_background_color: Color, pub bottom_background_color: Color, pub grid_lines_color: Color, pub graph_lines_color: Color, pub partial_fill_color: Color, pub complete_fill_color: Color, pub best_segment_color: Color, pub height: u32,
}
The state object describes the information to visualize for this component. All coordinates are in the range 0..1.

Fields

points: Vec<Point>

All of the graph’s points. Connect them to visualize the graph. If the live delta is active, the last point is to be interpreted as a preview of the next split. Use the partial fill color to visualize the region beneath that graph segment.

horizontal_grid_lines: Vec<f32>

The y-coordinates of all the horizontal grid lines.

vertical_grid_lines: Vec<f32>

The x-coordinates of all the vertical grid lines.

middle: f32

The y-coordinate of the x-axis.

is_live_delta_active: bool

If the live delta is active, the last point is to be interpreted as a preview of the next split. Use the partial fill color to visualize the region beneath that graph segment.

is_flipped: bool

Describes whether the chart is flipped vertically. For visualization, this can usually be ignored, as it is already regarded in the other variables.

top_background_color: Color

The background color of the region of the chart that is above the x-axis.

bottom_background_color: Color

The background color of the region of the chart that is below the x-axis.

grid_lines_color: Color

The color of the chart’s grid lines.

graph_lines_color: Color

The color of the lines connecting the graph’s points.

partial_fill_color: Color

The color of the region enclosed by the x-axis and the graph. The partial fill color is only used for live changes. More specifically, this color is used in the interval from the last split time to the current time.

complete_fill_color: Color

The color of the region enclosed by the x-axis and the graph, excluding the graph segment with live changes.

best_segment_color: Color

The color of the lines of graph segments that achieved a new best segment time.

height: u32

The height of the chart.

Implementations

Source

impl State

pub fn write_json<W>(&self, writer: W) -> Result<()>
where W: Write,

Encodes the state object’s information as JSON.