pub struct Component { /* private fields */ }Expand description
The Previous Segment Component is a component that shows how much time was
saved or lost during the previous Segment based on
the chosen comparison. Additionally, the potential time save for the previous
Segment can be displayed. This component switches
to a Live Segment view that shows active time loss whenever the runner is
losing time on the current Segment.
Implementations
Sourceimpl Component
impl Component
Sourcepub const fn with_settings(settings: Settings) -> Self
pub const fn with_settings(settings: Settings) -> Self
Creates a new Previous Segment Component with the given settings.
Sourcepub fn settings_mut(&mut self) -> &mut Settings
pub fn settings_mut(&mut self) -> &mut Settings
Grants mutable access to the settings of the component.
Sourcepub fn update_state(
&self,
state: &mut State,
timer: &Snapshot<'_>,
layout_settings: &GeneralLayoutSettings,
)
pub fn update_state( &self, state: &mut State, timer: &Snapshot<'_>, layout_settings: &GeneralLayoutSettings, )
Updates the component’s state based on the timer and layout settings provided.
Sourcepub fn state(
&self,
timer: &Snapshot<'_>,
layout_settings: &GeneralLayoutSettings,
) -> State
pub fn state( &self, timer: &Snapshot<'_>, layout_settings: &GeneralLayoutSettings, ) -> State
Calculates the component’s state based on the timer and the layout settings provided.
Sourcepub fn settings_description(&self) -> SettingsDescription
pub fn settings_description(&self) -> SettingsDescription
Accesses a generic description of the settings available for this component and their current values.
Sourcepub fn set_value(&mut self, index: usize, value: Value)
pub fn set_value(&mut self, index: usize, value: Value)
Sets a setting’s value by its index to the given value.
Panics
This panics if the type of the value to be set is not compatible with the type of the setting’s value. A panic can also occur if the index of the setting provided is out of bounds.