pub enum ColumnStartWith {
Empty,
ComparisonTime,
ComparisonSegmentTime,
PossibleTimeSave,
}Expand description
Specifies the value a segment starts out with before it gets replaced with the current attempt’s information when splitting.
Variants
Empty
The column starts out with an empty value.
ComparisonTime
The column starts out with the times stored in the comparison that is being compared against.
ComparisonSegmentTime
The column starts out with the segment times stored in the comparison that is being compared against.
PossibleTimeSave
The column starts out with the time that can be saved on each individual segment stored in the comparison that is being compared against.