pub enum ColumnUpdateTrigger {
OnStartingSegment,
Contextual,
OnEndingSegment,
}Expand description
Specifies when a column’s value gets updated.
Variants
OnStartingSegment
The value gets updated as soon as the segment is started. The value constantly updates until the segment ends.
Contextual
The value doesn’t immediately get updated when the segment is started. Instead the value constantly gets updated once the segment time is longer than the best segment time. The final update to the value happens when the segment ends.
OnEndingSegment
The value of a segment gets updated once the segment ends.