pub enum ColumnUpdateWith {
DontUpdate,
SplitTime,
Delta,
DeltaWithFallback,
SegmentTime,
SegmentDelta,
SegmentDeltaWithFallback,
}Expand description
Once a certain condition is met, which is usually being on the split or already having completed the split, the time gets updated with the value specified here.
Variants
DontUpdate
The value doesn’t get updated and stays on the value it started out with.
SplitTime
The value gets replaced by the current attempt’s split time.
Delta
The value gets replaced by the delta of the current attempt’s and the comparison’s split time.
DeltaWithFallback
The value gets replaced by the delta of the current attempt’s and the comparison’s split time. If there is no delta, the value gets replaced by the current attempt’s split time instead.
SegmentTime
The value gets replaced by the current attempt’s segment time.
SegmentDelta
The value gets replaced by the current attempt’s time saved or lost, which is how much faster or slower the current attempt’s segment time is compared to the comparison’s segment time. This matches the Previous Segment component.
SegmentDeltaWithFallback
The value gets replaced by the current attempt’s time saved or lost, which is how much faster or slower the current attempt’s segment time is compared to the comparison’s segment time. This matches the Previous Segment component. If there is no time saved or lost, then value gets replaced by the current attempt’s segment time instead.