pub struct Component { /* private fields */ }Expand description
The Splits Component is the main component for visualizing all the split
times. Each Segment is shown in a tabular fashion
showing the segment icon, segment name, the delta compared to the chosen
comparison, and the split time.
The list provides scrolling functionality, so not every segment needs
to be shown all the time.
Implementations
Sourceimpl Component
impl Component
Sourcepub fn with_settings(settings: Settings) -> Self
pub fn with_settings(settings: Settings) -> Self
Creates a new Splits Component with the given settings.
Sourcepub fn settings_mut(&mut self) -> &mut Settings
pub fn settings_mut(&mut self) -> &mut Settings
Grants mutable access to the settings of the component.
Sourcepub fn scroll_up(&mut self)
pub fn scroll_up(&mut self)
Scrolls up the window of the segments that are shown. Doesn’t move the scroll window if it reaches the top of the segments.
Sourcepub fn scroll_down(&mut self)
pub fn scroll_down(&mut self)
Scrolls down the window of the segments that are shown. Doesn’t move the scroll window if it reaches the bottom of the segments.
Sourcepub fn remount(&mut self)
pub fn remount(&mut self)
Remounts the component as if it was freshly initialized. The segment icons shown by this component are only provided in the state objects whenever the icon changes or whenever the component’s state is first queried. Remounting returns the segment icons again, whenever its state is queried the next time.
Sourcepub fn update_state(
&mut self,
state: &mut State,
timer: &Snapshot<'_>,
layout_settings: &GeneralLayoutSettings,
)
pub fn update_state( &mut self, state: &mut State, timer: &Snapshot<'_>, layout_settings: &GeneralLayoutSettings, )
Updates the component’s state based on the timer and layout settings provided.
Sourcepub fn state(
&mut self,
timer: &Snapshot<'_>,
layout_settings: &GeneralLayoutSettings,
) -> State
pub fn state( &mut self, timer: &Snapshot<'_>, layout_settings: &GeneralLayoutSettings, ) -> State
Calculates the component’s state based on the timer and layout settings provided.
Sourcepub fn settings_description(&self) -> SettingsDescription
pub fn settings_description(&self) -> SettingsDescription
Accesses a generic description of the settings available for this component and their current values.
Sourcepub fn set_value(&mut self, index: usize, value: Value)
pub fn set_value(&mut self, index: usize, value: Value)
Sets a setting’s value by its index to the given value.
Panics
This panics if the type of the value to be set is not compatible with the type of the setting’s value. A panic can also occur if the index of the setting provided is out of bounds.