SplitState

Struct SplitState 

pub struct SplitState {
    pub name: String,
    pub columns: ClearVec<ColumnState>,
    pub is_current_split: bool,
    pub index: usize,
}
The state object that describes a single segment’s information to visualize.

Fields

name: String

The name of the segment.

columns: ClearVec<ColumnState>

The state of each column from right to left. The amount of columns is not guaranteed to be the same across different splits.

is_current_split: bool

Describes if this segment is the segment the active attempt is currently on.

index: usize

The index of the segment based on all the segments of the run. This may differ from the index of this SplitState in the State object, as there can be a scrolling window, showing only a subset of segments. Each index is guaranteed to be unique.