pub struct TimeColumn {
pub start_with: ColumnStartWith,
pub update_with: ColumnUpdateWith,
pub update_trigger: ColumnUpdateTrigger,
pub comparison_override: Option<String>,
pub timing_method: Option<TimingMethod>,
}Expand description
A column that shows a time.
Fields
start_with: ColumnStartWithSpecifies the value a segment starts out with before it gets replaced with the current attempt’s information when splitting.
update_with: ColumnUpdateWithOnce a certain condition is met, which is usually being on the split or already having completed the split, the time gets updated with the value specified here.
update_trigger: ColumnUpdateTriggerSpecifies when a column’s value gets updated.
comparison_override: Option<String>The comparison chosen. Uses the Timer’s current comparison if set to
None.
timing_method: Option<TimingMethod>Specifies the Timing Method to use. If set to None the Timing Method
of the Timer is used for showing the time. Otherwise the Timing Method
provided is used.