pub struct Component { /* private fields */ }Expand description
The Text Component simply visualizes any given text. This can either be a single centered text, or split up into a left and right text, which is suitable for a situation where you have a label and a value.
Implementations
Sourceimpl Component
impl Component
Sourcepub const fn with_settings(settings: Settings) -> Self
pub const fn with_settings(settings: Settings) -> Self
Creates a new Text Component with the given settings.
Sourcepub fn settings_mut(&mut self) -> &mut Settings
pub fn settings_mut(&mut self) -> &mut Settings
Grants mutable access to the settings of the component.
Sourcepub fn update_state(&self, state: &mut State, timer: &Timer)
pub fn update_state(&self, state: &mut State, timer: &Timer)
Updates the component’s state based on the timer provided.
Sourcepub fn settings_description(&self) -> SettingsDescription
pub fn settings_description(&self) -> SettingsDescription
Accesses a generic description of the settings available for this component and their current values.
Sourcepub fn set_value(&mut self, index: usize, value: Value)
pub fn set_value(&mut self, index: usize, value: Value)
Sets a setting’s value by its index to the given value.
Panics
This panics if the type of the value to be set is not compatible with the type of the setting’s value. A panic can also occur if the index of the setting provided is out of bounds.