Settings

Struct Settings 

pub struct Settings {
    pub background: DeltaGradient,
    pub timing_method: Option<TimingMethod>,
    pub height: u32,
    pub color_override: Option<Color>,
    pub show_gradient: bool,
    pub digits_format: DigitsFormat,
    pub accuracy: Accuracy,
    pub is_segment_timer: bool,
}
The Settings for this component.

Fields

background: DeltaGradient

The background shown behind the component.

timing_method: Option<TimingMethod>

Specifies the Timing Method to use. If set to None the Timing Method of the Timer is used for showing the time. Otherwise the Timing Method provided is used.

height: u32

The height of the timer.

color_override: Option<Color>

Instead of automatically determining the color of the time shown, based on a how well the current attempt is doing, a specific color to always be used can be provided instead.

show_gradient: bool

The Timer Component automatically converts the color it is supposed to use into a gradient and shows that. If this is set to false the actual color is used instead of a gradient.

digits_format: DigitsFormat

Determines how many digits are to always be shown. If the duration is lower than the digits to be shown, they are filled up with zeros.

accuracy: Accuracy

The accuracy of the time shown.

is_segment_timer: bool

Specifies whether to show the how much time has passed since the start current segment, rather than how much time has passed since the start of the current attempt.