State

Struct State 

pub struct State {
    pub background: Gradient,
    pub text_color: Option<Color>,
    pub icon_change: Option<ImageData>,
    pub line1: Vec<Box<str>>,
    pub line2: Vec<Box<str>>,
    pub is_centered: bool,
    pub finished_runs: Option<u32>,
    pub attempts: Option<u32>,
}
The state object describes the information to visualize for this component.

Fields

background: Gradient

The background shown behind the component.

text_color: Option<Color>

The color of the text. If None is specified, the color is taken from the layout.

icon_change: Option<ImageData>

The game’s icon encoded as the raw file bytes. This value is only specified whenever the icon changes. If you explicitly want to query this value, remount the component. The buffer itself may be empty. This indicates that there is no icon.

line1: Vec<Box<str>>

The first title line to show. This is either the game’s name, or a combination of the game’s name and the category. This is a list of all the possible abbreviations. It contains at least one element and the last element is the unabbreviated value.

line2: Vec<Box<str>>

By default the category name is shown on the second line. Based on the settings, it can however instead be shown in a single line together with the game name. This is a list of all the possible abbreviations. If this is empty, only a single line is supposed to be shown. If it contains at least one element, the last element is the unabbreviated value.

is_centered: bool

Specifies whether the title should centered or aligned to the left instead.

finished_runs: Option<u32>

The amount of successfully finished attempts. If None is specified, the amount of successfully finished attempts isn’t supposed to be shown.

attempts: Option<u32>

The amount of total attempts. If None is specified, the amount of total attempts isn’t supposed to be shown.

Implementations

Source

impl State

pub fn write_json<W>(&self, writer: W) -> Result<()>
where W: Write,

Encodes the state object’s information as JSON.