pub struct ButtonsState {
pub can_remove: bool,
pub can_move_up: bool,
pub can_move_down: bool,
}Expand description
Describes which actions are currently available. Depending on how many components exist and which one is selected, only some actions can be executed successfully.
Fields
can_remove: boolDescribes whether the currently selected component can be removed. If there’s only one component in the layout, it can’t be removed.
can_move_up: boolDescribes whether the currently selected component can be moved up. If the first component is selected, it can’t be moved.
can_move_down: boolDescribes whether the currently selected component can be moved down. If the last component is selected, it can’t be moved.