Component

Enum Component 

pub enum Component {
Show 17 variants BlankSpace(Component), CurrentComparison(Component), CurrentPace(Component), Delta(Component), DetailedTimer(Box<Component>), Graph(Component), PbChance(Component), PossibleTimeSave(Component), PreviousSegment(Component), SegmentTime(Component), Separator(Component), Splits(Component), SumOfBest(Component), Text(Component), Timer(Component), Title(Component), TotalPlaytime(Component),
}
A Component provides information about a run in a way that is easy to visualize. This type can store any of the components provided by this crate.

Variants



BlankSpace(Component)

The Blank Space Component.



CurrentComparison(Component)

The Current Comparison Component.



CurrentPace(Component)

The Current Pace Component.



Delta(Component)

The Delta Component.



DetailedTimer(Box<Component>)

The Detailed Timer Component.



Graph(Component)

The Graph Component.



PbChance(Component)

The PB Chance Component.



PossibleTimeSave(Component)

The Possible Time Save Component.



PreviousSegment(Component)

The Previous Segment Component.



SegmentTime(Component)

The Segment Time Component.



Separator(Component)

The Separator Component.



Splits(Component)

The Splits Component.



SumOfBest(Component)

The Sum of Best Component.



Text(Component)

The Text Component.



Timer(Component)

The Timer Component.



Title(Component)

The Title Component.



TotalPlaytime(Component)

The Total Playtime Component.

Implementations

Source

impl Component

pub fn update_state( &mut self, state: &mut ComponentState, timer: &Snapshot<'_>, layout_settings: &GeneralSettings, )

Updates the component’s state based on the timer and settings provided. The timer provides the information to visualize and the layout settings provide general information about how to expose that information in the state.

pub fn state( &mut self, timer: &Snapshot<'_>, layout_settings: &GeneralSettings, ) -> ComponentState

Calculates the component’s state based on the timer and settings provided. The timer provides the information to visualize and the layout settings provide general information about how to expose that information in the state.

pub fn settings(&self) -> ComponentSettings

Accesses the settings of the component. Each component has different settings, so you need to handle them on a case by case basis. If you want to access a more general description of the settings, access the Settings Description instead.

pub fn name(&self) -> Cow<'_, str>

Accesses the name of the component.

pub fn scroll_up(&mut self)

Tells the component to scroll up. This may be interpreted differently based on the kind of component. Most components will ignore this.

pub fn scroll_down(&mut self)

Tells the component to scroll down. This may be interpreted differently based on the kind of component. Most components will ignore this.

pub fn remount(&mut self)

Some component states provide relative information based on information they already provided. Remounting forces the components to provide absolute information again, as if they provide the state for the first time.

pub fn settings_description(&self) -> SettingsDescription

Provides a general description of the settings. Such a Settings Description entirely describes all the settings that are available, what type they are and what value they currently have. This provides a user interface independent way of changing the settings.

pub fn set_value(&mut self, index: usize, value: Value)

Changes a setting of the component based on its Settings Description index.

Panics

This may panic if the index doesn’t match any setting provided by the Settings Description of this component. Additionally, the value needs to have a compatible type.