pub enum ComponentState {
BlankSpace(State),
DetailedTimer(Box<State>),
Graph(State),
KeyValue(State),
Separator(State),
Splits(State),
Text(State),
Timer(State),
Title(State),
}Expand description
The state object for one of the components available.
Variants
BlankSpace(State)
The state object for the Blank Space Component.
DetailedTimer(Box<State>)
The state object for the Detailed Timer Component.
Graph(State)
The state object for the Graph Component.
KeyValue(State)
The state object for a key value based component.
Separator(State)
The state object for the Separator Component.
Splits(State)
The state object for the Splits Component.
Text(State)
The state object for the Text Component.
Timer(State)
The state object for the Timer Component.
Title(State)
The state object for the Title Component.