Module parser

Module parser 

Provides the parser for layout files of the original LiveSplit.

Enums

Error
The Error type for parsing layout files of the original LiveSplit.

Functions

parse
Attempts to parse a layout file of the original LiveSplit. They are only parsed on a best effort basis, so if something isn’t supported by livesplit-core, then it will be parsed without that option.

Type Aliases

Result
The Result type for parsing layout files of the original LiveSplit.