parse

Function parse 

pub fn parse(source: &str) -> Result<Layout>
Attempts to parse a layout file of the original LiveSplit. They are only parsed on a best effort basis, so if something isn’t supported by livesplit-core, then it will be parsed without that option.