pub enum Entity<P, I, L> {
FillPath(Handle<P>, FillShader, Transform),
StrokePath(Handle<P>, f32, Rgba, Transform),
Image(Handle<I>, Transform),
Label(LabelHandle<L>, FillShader, Transform),
}Expand description
Variants
FillPath(Handle<P>, FillShader, Transform)
A path where the inside is filled with the FillShader. For
determining what’s inside the non-zero fill
rule
is supposed to be used.
StrokePath(Handle<P>, f32, Rgba, Transform)
A path where only the path lines themselves are supposed to be drawn. There is no notion of an inside region. The floating point number determines the thickness of the path.
Image(Handle<I>, Transform)
An image.
Label(LabelHandle<L>, FillShader, Transform)
A text label.