Module path_based_text_engine

Module path_based_text_engine 

An optional path based text engine is provided that allows you to create fonts and manage text labels that are based on paths. That way the underlying renderer doesn’t by itself need to be able to render text, as all the text gets turned into paths.

Structs

Font
The font to use in the ResourceAllocator.
Glyph
A glyph to render.
LockedLabel
You need to lock the Label to use it. This is the locked type that provides all the methods you need to use the label.
TextEngine
The path based text engine allows you to create fonts and manage text labels that are based on paths. That way the underlying renderer doesn’t by itself need to be able to render text, as all the text gets turned into paths.

Type Aliases

Label
The label to use in the ResourceAllocator.