pub struct BorrowedRenderer { /* private fields */ }Expand description
The software renderer allows rendering layouts entirely on the CPU. This is surprisingly fast and can be considered the default renderer. There are two versions of the software renderer. This version of the software renderer does not own the image to render into. This allows the caller to manage their own image buffer.
Implementations
Sourceimpl BorrowedRenderer
impl BorrowedRenderer
Sourcepub fn render(
&mut self,
state: &LayoutState,
image: &mut [u8],
[width, height]: [u32; 2],
stride: u32,
force_redraw: bool,
) -> Option<(f32, f32)>
pub fn render( &mut self, state: &LayoutState, image: &mut [u8], [width, height]: [u32; 2], stride: u32, force_redraw: bool, ) -> Option<(f32, f32)>
Renders the layout state provided into the image buffer provided. The
image has to be an array of RGBA8 encoded pixels (red, green, blue,
alpha with each channel being an u8). Some frameworks may over allocate
an image’s dimensions. So an image with dimensions 100x50 may be over
allocated as 128x64. In that case you provide the real dimensions of
100x50 as the width and height, but a stride of 128 pixels as that
correlates with the real width of the underlying buffer. It may detect
that the layout got resized. In that case it returns the new ideal size.
This is just a hint and can be ignored entirely. The image is always
rendered with the resolution provided. By default the renderer will try
not to redraw parts of the image that haven’t changed. You can force a
redraw in case the image provided or its contents have changed.