pub struct Renderer { /* private fields */ }Expand description
The software renderer allows rendering layouts entirely on the CPU. This is surprisingly fast and can be considered the default renderer. There are two versions of the software renderer. This version of the software renderer owns the image it renders into.
Implementations
Sourceimpl Renderer
impl Renderer
Sourcepub fn render(
&mut self,
state: &LayoutState,
[width, height]: [u32; 2],
) -> Option<(f32, f32)>
pub fn render( &mut self, state: &LayoutState, [width, height]: [u32; 2], ) -> Option<(f32, f32)>
Renders the layout state provided with the chosen resolution. It may detect that the layout got resized. In that case it returns the new ideal size. This is just a hint and can be ignored entirely. The image is always rendered with the resolution provided.
Sourcepub fn image_data(&self) -> &[u8] ⓘ
pub fn image_data(&self) -> &[u8] ⓘ
Accesses the image as a byte slice of RGBA8 encoded pixels (red, green, blue, alpha with each channel being an u8).
Sourcepub fn into_image_data(self) -> Vec<u8> ⓘ
pub fn into_image_data(self) -> Vec<u8> ⓘ
Turns the whole renderer into the underlying image buffer of RGBA8 encoded pixels (red, green, blue, alpha with each channel being an u8).
Sourcepub fn into_image(self) -> RgbaImage
pub fn into_image(self) -> RgbaImage
Turns the whole renderer into the underlying image.