pub struct Scene<P, I, L> { /* private fields */ }Expand description
A scene describes all the Entities to visualize. It consists of
two Layers that are supposed to be composited on top of each
other. The bottom Layer changes infrequently and doesn’t need to be
rerendered for most frames. The top Layer contains all the per frame
changes and needs to be rerendered for every frame. If however it is empty
and both the bottom layer didn’t change, then no new frame needs to be
rendered. While the top Layer is inherently transparent, the bottom
Layer has a background that needs to be considered.
Implementations
Sourceimpl<P: SharedOwnership, I: SharedOwnership, L: SharedOwnership> Scene<P, I, L>
impl<P: SharedOwnership, I: SharedOwnership, L: SharedOwnership> Scene<P, I, L>
Sourcepub fn new(rectangle: Handle<P>) -> Self
pub fn new(rectangle: Handle<P>) -> Self
Creates a new scene with the rectangle provided to use for placing rectangle entities.
Sourcepub const fn background(&self) -> &Option<FillShader>
pub const fn background(&self) -> &Option<FillShader>
Sourcepub const fn bottom_layer_changed(&self) -> bool
pub const fn bottom_layer_changed(&self) -> bool
Sourcepub fn bottom_layer(&self) -> &[Entity<P, I, L>]
pub fn bottom_layer(&self) -> &[Entity<P, I, L>]
Sourcepub fn set_background(&mut self, background: Option<FillShader>)
pub fn set_background(&mut self, background: Option<FillShader>)
Set the bottom Layer's background.
Sourcepub fn bottom_layer_mut(&mut self) -> &mut Vec<Entity<P, I, L>>
pub fn bottom_layer_mut(&mut self) -> &mut Vec<Entity<P, I, L>>
Get a mutable reference to the scene’s bottom Layer.
Sourcepub fn top_layer_mut(&mut self) -> &mut Vec<Entity<P, I, L>>
pub fn top_layer_mut(&mut self) -> &mut Vec<Entity<P, I, L>>
Get a mutable reference to the scene’s top Layer.
Sourcepub fn recalculate_if_bottom_layer_changed(&mut self)
pub fn recalculate_if_bottom_layer_changed(&mut self)