parse

Function parse 

pub fn parse(
    source: &str,
    path_for_loading_other_files: Option<&Path>,
) -> Result<Run>
Attempts to parse a Time Split Tracker splits file. In addition to the source to parse, you can specify the path of the splits file, which is then use to load the run log file from the file system. This is entirely optional. If you are using livesplit-core in a server-like environment, set this to None. Only client-side applications should provide the path here.