pub struct CustomVariable {
pub value: String,
pub is_permanent: bool,
}Expand description
A custom variable is a key value pair storing additional information about a run. Unlike the speedrun.com variables, these can be fully custom and don’t need to correspond to anything on speedrun.com. Permanent custom variables can be specified by the runner. Additionally auto splitters or other sources may provide temporary custom variables that are not stored in the splits files.
Fields
value: StringThe current value of the custom variable. This may be provided by the runner in the run editor or it may be provided through other means such as an auto splitter.
is_permanent: boolStates whether the variable is permanent. Temporary variables don’t get stored in splits files. They also don’t get shown in the run editor.
Implementations
Sourceimpl CustomVariable
impl CustomVariable
Sourcepub fn permanent(&mut self) -> &mut Self
pub fn permanent(&mut self) -> &mut Self
Turns the custom variable into a permanent one. If it already is permanent variable, nothing happens.
Sourcepub fn set_value<S>(&mut self, value: S)where
S: PopulateString,
pub fn set_value<S>(&mut self, value: S)where
S: PopulateString,
Sets the value of the custom variable.
Sourcepub fn clear_value(&mut self)
pub fn clear_value(&mut self)
Clears the value of the custom variable. This does not delete the custom variable.