pub enum CachedImageId {
Uncached,
NoImage,
Image(usize),
}Expand description
With a Cached Image ID you can track image changes. It starts with an uncached state and then gets updated with the images provided to it. It can be reset at any point in order to force a change to be detected.
Variants
Uncached
The initial uncached state.
NoImage
The last image observed either was missing or contained no data.
Image(usize)
The last image had actual data and the ID stored here.
Implementations
Sourceimpl CachedImageId
impl CachedImageId
Sourcepub fn update_with<'i>(&mut self, image: Option<&'i Image>) -> Option<&'i [u8]>
pub fn update_with<'i>(&mut self, image: Option<&'i Image>) -> Option<&'i [u8]>
Updates the cached image ID based on the optional image provided to this method. If a change is observed the image’s data is returned. An empty slice is returned when a transition to no image or no image data is observed.