pub struct Complete;Expand description
The Complete Time Formatter formats a TimeSpan in a way that preserves as
much information as possible. The hours and minutes are always shown and a
fractional part of 9 digits is used. If there’s >24h, then a day prefix is
attached (with the hours wrapping around to 0): dd.hh:mm:ss.fffffffff
This formatter uses an ASCII minus for negative times and shows a zero time for empty times.
Example Formatting
- Empty Time
00:00:00.000000000 - Seconds
00:00:23.123400000 - Minutes
00:12:34.987654321 - Hours
12:34:56.123456789 - Negative Times
-12:34:56.123456789 - Days
89.12:34:56.123456789
Implementations