pub struct Delta(/* private fields */);Expand description
The Delta Time Formatter formats a TimeSpan as a comparison of two
durations, so that it visualizes the difference between both of them.
Therefore it always shows whether it is a positive or negative difference,
by prepending a plus or minus sign. You can choose how many digits of the
fractional part are visualized. Additionally there’s an option for removing
the fractional part for deltas that are larger than 1 minute.
Example Formatting
- Empty Time
— - Seconds
+23.1 - Minutes without Decimal Dropping
+12:34.9 - Minutes with Decimal Dropping
+12:34 - Hours without Decimal Dropping
+12:34:56.1 - Hours with Decimal Dropping
+12:34:56 - Negative Times
−23.1
Implementations
Sourceimpl Delta
impl Delta
Sourcepub const fn new() -> Self
pub const fn new() -> Self
Creates a new default Delta Time Formatter that drops the fractional part and uses tenths when showing the fractional part.
Sourcepub const fn custom(drop_decimals: bool, accuracy: Accuracy) -> Self
pub const fn custom(drop_decimals: bool, accuracy: Accuracy) -> Self
Creates a new custom Delta Time Formatter where you can specify whether the fractional part should be dropped for deltas that are larger than 1 minute and how many digits to show for the fractional part.
Sourcepub const fn with_decimal_dropping() -> Self
pub const fn with_decimal_dropping() -> Self
Creates a new Delta Time Formatter that drops the fractional part and uses tenths when showing the fractional part.