Regular

Struct Regular 

pub struct Regular { /* private fields */ }
The Regular Time Formatter formats a TimeSpan to always show the minutes and is configurable by how many digits of the fractional part are shown. By default no fractional part is shown. This Time Formatter is most suitable for visualizing split times.

Example Formatting

  • Empty Time
  • Seconds 0:23
  • Minutes 12:34
  • Hours 12:34:56
  • Seconds with Hundredths 0:23.12
  • Minutes with Hundredths 12:34.98
  • Hours with Hundredths 12:34:56.12
  • Negative Times −0:23

Implementations

Source

impl Regular

pub const fn new() -> Self

Creates a new default Regular Time Formatter that doesn’t show a fractional part.

pub const fn with_accuracy(accuracy: Accuracy) -> Self

Creates a new custom Regular Time Formatter where you can specify how many digits to show for the fractional part.