pub struct SegmentTime { /* private fields */ }Expand description
The Segment Time Formatter formats a TimeSpan for them to be shown as
Segment Times. This specifically means that the fractional part of the time
is always shown and the minutes and hours are only shown when necessary. The
default accuracy is to show 2 digits of the fractional part, but this can be
configured.
Example Formatting
- Empty Time
— - Seconds
23.12 - Minutes
12:34.98 - Hours
12:34:56.12 - Negative Times
−23.12
Implementations
Sourceimpl SegmentTime
impl SegmentTime
Sourcepub const fn new() -> Self
pub const fn new() -> Self
Creates a new Segment Time Formatter that uses hundredths for showing the fractional part.
Sourcepub const fn with_accuracy(accuracy: Accuracy) -> Self
pub const fn with_accuracy(accuracy: Accuracy) -> Self
Creates a new Segment Time Formatter that uses the accuracy provided for showing the fractional part.