pub struct AtomicDateTime {
pub time: DateTime,
pub synced_with_atomic_clock: bool,
}Expand description
An Atomic Date Time represents a UTC DateTime that tries to be as close to
an atomic clock as possible.
Fields
time: DateTimeThe UTC Date Time represented by this Atomic Date Time.
synced_with_atomic_clock: boolRepresents whether the date time is actually properly derived from an
atomic clock. If the synchronization with the atomic clock didn’t happen
yet or failed, this is set to false.
Implementations
Sourceimpl AtomicDateTime
impl AtomicDateTime
Sourcepub const fn new(time: DateTime, synced_with_atomic_clock: bool) -> Self
pub const fn new(time: DateTime, synced_with_atomic_clock: bool) -> Self
Creates a new Atomic Date Time from the UTC Date Time and the information of whether this Date Time is derived from an atomic clock or the local system that may be out of sync with the atomic clock.
Sourcepub fn now() -> Self
pub fn now() -> Self
Creates a new Atomic Date Time that describes the current moment in time. If a successful synchronization with an atomic clock occurred, this value is marked as synchronized. Otherwise the local system’s timer is used.
Warning
livesplit-core doesn’t synchronize with any atomic clock yet.