pub struct Time {
pub real_time: Option<TimeSpan>,
pub game_time: Option<TimeSpan>,
}Expand description
A time that can store a Real Time and a Game Time. Both of them are optional.
Fields
real_time: Option<TimeSpan>The Real Time value.
game_time: Option<TimeSpan>The Game Time value.
Implementations
Sourceimpl Time
impl Time
Sourcepub const fn zero() -> Self
pub const fn zero() -> Self
Creates a new Time where Real Time and Game Time are zero. Keep in mind
that a zero Time Span is not the same as a None Time Span as created
by Time::new().
Sourcepub const fn with_real_time(self, real_time: Option<TimeSpan>) -> Self
pub const fn with_real_time(self, real_time: Option<TimeSpan>) -> Self
Creates a new Time based on the current one where the Real Time is replaced by the given Time Span.
Sourcepub const fn with_game_time(self, game_time: Option<TimeSpan>) -> Self
pub const fn with_game_time(self, game_time: Option<TimeSpan>) -> Self
Creates a new Time based on the current one where the Game Time is replaced by the given Time Span.
Sourcepub fn with_timing_method(
self,
timing_method: TimingMethod,
time: Option<TimeSpan>,
) -> Self
pub fn with_timing_method( self, timing_method: TimingMethod, time: Option<TimeSpan>, ) -> Self
Creates a new Time based on the current one where the specified timing method is replaced by the given Time Span.