pub struct Settings {
pub comparison_override: Option<String>,
pub show_best_segments: bool,
pub live_graph: bool,
pub flip_graph: bool,
pub behind_background_color: Color,
pub ahead_background_color: Color,
pub grid_lines_color: Color,
pub graph_lines_color: Color,
pub partial_fill_color: Color,
pub complete_fill_color: Color,
pub height: u32,
}Expand description
The Settings for this component.
Fields
comparison_override: Option<String>The comparison chosen. Uses the Timer’s current comparison if set to
None.
show_best_segments: boolSpecifies if the best segments should be colored with the layout’s best segment color.
live_graph: boolSpecifies if the graph should automatically adjust to all changes. If this is deactivated, changes to the graph only happen whenever the current segment changes.
flip_graph: boolFlips the chart. If set to false, split times which are ahead of the
comparison are displayed below the x-axis and times which are behind are
above it. Enabling this settings flips it.
behind_background_color: ColorThe background color for the chart region containing the times that are behind the comparison.
ahead_background_color: ColorThe background color for the chart region containing the times that are ahead of the comparison.
grid_lines_color: ColorThe color of the chart’s grid lines.
graph_lines_color: ColorThe color of the lines connecting the graph’s points.
partial_fill_color: ColorThe color of the region enclosed by the x-axis and the graph. The partial fill color is only used for live changes. More specifically, this color is used in the interval from the last split time to the current time.
complete_fill_color: ColorThe color of the region enclosed by the x-axis and the graph, excluding the graph segment with live changes.
height: u32The height of the chart.