pub struct State {
pub background: ListGradient,
pub column_labels: Option<ClearVec<String>>,
pub splits: ClearVec<SplitState>,
pub icon_changes: Vec<IconChange>,
pub has_icons: bool,
pub show_thin_separators: bool,
pub show_final_separator: bool,
pub display_two_rows: bool,
pub current_split_gradient: Gradient,
}Expand description
The state object describes the information to visualize for this component.
Fields
background: ListGradientThe background shown behind the splits.
column_labels: Option<ClearVec<String>>The column labels to visualize about the list of splits. If this is
None, no labels are supposed to be visualized. The list is specified
from right to left.
splits: ClearVec<SplitState>The list of all the segments to visualize.
icon_changes: Vec<IconChange>This list describes all the icon changes that happened. Each time a segment is first shown or its icon changes, the new icon is provided in this list. If necessary, you may remount this component to reset the component into a state where these icons are provided again.
has_icons: boolSpecifies whether the current run has any icons, even those that are not currently visible by the splits component. This allows for properly indenting the icon column, even when the icons are scrolled outside the splits component.
show_thin_separators: boolSpecifies whether thin separators should be shown between the individual segments shown by the component.
show_final_separator: boolDescribes whether a more pronounced separator should be shown in front of the last segment provided.
display_two_rows: boolSpecifies whether to display each split as two rows, with the segment name being in one row and the times being in the other.
current_split_gradient: GradientThe gradient to show behind the current segment as an indicator of it being the current segment.
Implementations