Provides the Timer Component and relevant types for using it. The Timer
Component is a component that shows the total time of the current attempt as
a digital clock. The color of the time shown is based on a how well the
current attempt is doing compared to the chosen comparison.
Structs
- Component
- The
TimerComponent is a component that shows the total time of the current attempt as a digital clock. The color of the time shown is based on a how well the current attempt is doing compared to the chosen comparison. - Settings
- The Settings for this component.
- State
- The state object describes the information to visualize for this component.
Enums
- Delta
Gradient - Represents the possible backgrounds for a timer.
Functions
- top_
and_ bottom_ color - Calculates the top and bottom color the Timer Component would use for the gradient of the times it is showing.