Provides a software renderer that can be used without a GPU. The renderer is surprisingly fast and can be considered the default rendering backend.
Re-exports
pub use image;
Structs
- Borrowed
Renderer - The software renderer allows rendering layouts entirely on the CPU. This is surprisingly fast and can be considered the default renderer. There are two versions of the software renderer. This version of the software renderer does not own the image to render into. This allows the caller to manage their own image buffer.
- Renderer
- The software renderer allows rendering layouts entirely on the CPU. This is surprisingly fast and can be considered the default renderer. There are two versions of the software renderer. This version of the software renderer owns the image it renders into.
Type Aliases
- Rgba
Image - Sendable Rgb + alpha channel image buffer