pub struct State {
pub icon_change: Option<ImageData>,
pub game: String,
pub category: String,
pub offset: String,
pub attempts: u32,
pub timing_method: TimingMethod,
pub segments: Vec<Segment>,
pub comparison_names: Vec<String>,
pub buttons: Buttons,
pub metadata: RunMetadata,
}Expand description
Represents the current state of the Run Editor in order to visualize it properly.
Fields
icon_change: Option<ImageData>The game’s icon encoded as the raw file bytes. This value is only specified whenever the icon changes. The buffer itself may be empty. This indicates that there is no icon.
game: StringThe name of the game the Run is for.
category: StringThe name of the category the Run is for.
offset: StringThe timer offset specifies the time that the timer starts at when starting a new attempt.
attempts: u32The number of times this Run has been attempted by the runner. This is mostly just a visual number and has no effect on any history.
timing_method: TimingMethodThe timing method that is currently selected to be visualized and edited.
segments: Vec<Segment>The state of all the segments.
comparison_names: Vec<String>The names of all the custom comparisons that exist for this Run.
Describes which actions are currently available.
metadata: RunMetadataAdditional metadata of this Run, like the platform and region of the game.
Implementations