pub struct HotkeyConfig {
pub split: Option<Hotkey>,
pub reset: Option<Hotkey>,
pub undo: Option<Hotkey>,
pub skip: Option<Hotkey>,
pub pause: Option<Hotkey>,
pub undo_all_pauses: Option<Hotkey>,
pub previous_comparison: Option<Hotkey>,
pub next_comparison: Option<Hotkey>,
pub toggle_timing_method: Option<Hotkey>,
}Expand description
The configuration to use for a HotkeySystem. It describes which Hotkey to use as hotkeys for the different actions.
Fields
split: Option<Hotkey>The key to use for splitting and starting a new attempt.
reset: Option<Hotkey>The key to use for resetting the current attempt.
undo: Option<Hotkey>The key to use for undoing the last split.
skip: Option<Hotkey>The key to use for skipping the current split.
pause: Option<Hotkey>The key to use for pausing the current attempt and starting a new attempt.
undo_all_pauses: Option<Hotkey>The key to use for removing all the pause times from the current time.
previous_comparison: Option<Hotkey>The key to use for switching to the previous comparison.
next_comparison: Option<Hotkey>The key to use for switching to the next comparison.
toggle_timing_method: Option<Hotkey>The key to use for toggling between the Real Time and Game Time
timing methods.
Implementations
Sourceimpl HotkeyConfig
impl HotkeyConfig
Sourcepub fn settings_description(&self) -> SettingsDescription
pub fn settings_description(&self) -> SettingsDescription
Accesses a generic description of the settings available for the hotkey configuration and their current values.
Sourcepub fn set_value(&mut self, index: usize, value: Value) -> Result<(), ()>
pub fn set_value(&mut self, index: usize, value: Value) -> Result<(), ()>
Sets a setting’s value by its index to the given value.
Errors
An error is returned if a hotkey is already in use by a different action.
Panics
This panics if the type of the value to be set is not compatible with the type of the setting’s value. A panic can also occur if the index of the setting provided is out of bounds.
Sourcepub fn from_json<R>(reader: R) -> Result<Self>where
R: Read,
pub fn from_json<R>(reader: R) -> Result<Self>where
R: Read,
Decodes the hotkey configuration from JSON.
Sourcepub fn write_json<W>(&self, writer: W) -> Result<()>where
W: Write,
pub fn write_json<W>(&self, writer: W) -> Result<()>where
W: Write,
Encodes the hotkey configuration as JSON.