pub struct HotkeySystem { /* private fields */ }Expand description
With a HotkeySystem the runner can use hotkeys on their keyboard to control
the Timer. The hotkeys are global, so the application doesn’t need to be in
focus. The behavior of the hotkeys depends on the platform and is stubbed
out on platforms that don’t support hotkeys. You can turn off a HotkeySystem
temporarily. By default the HotkeySystem is activated.
Implementations
Sourceimpl HotkeySystem
impl HotkeySystem
Sourcepub fn new(timer: SharedTimer) -> Result<Self>
pub fn new(timer: SharedTimer) -> Result<Self>
Creates a new Hotkey System for a Timer with the default hotkeys.
Sourcepub fn with_config(timer: SharedTimer, config: HotkeyConfig) -> Result<Self>
pub fn with_config(timer: SharedTimer, config: HotkeyConfig) -> Result<Self>
Creates a new Hotkey System for a Timer with a custom configuration for the hotkeys.
Sourcepub fn set_split(&mut self, hotkey: Option<Hotkey>) -> Result<()>
pub fn set_split(&mut self, hotkey: Option<Hotkey>) -> Result<()>
Sets the key to use for splitting and starting a new attempt.
Sourcepub fn set_reset(&mut self, hotkey: Option<Hotkey>) -> Result<()>
pub fn set_reset(&mut self, hotkey: Option<Hotkey>) -> Result<()>
Sets the key to use for resetting the current attempt.
Sourcepub fn set_pause(&mut self, hotkey: Option<Hotkey>) -> Result<()>
pub fn set_pause(&mut self, hotkey: Option<Hotkey>) -> Result<()>
Sets the key to use for pausing the current attempt and starting a new attempt.
Sourcepub fn set_skip(&mut self, hotkey: Option<Hotkey>) -> Result<()>
pub fn set_skip(&mut self, hotkey: Option<Hotkey>) -> Result<()>
Sets the key to use for skipping the current split.
Sourcepub fn set_undo(&mut self, hotkey: Option<Hotkey>) -> Result<()>
pub fn set_undo(&mut self, hotkey: Option<Hotkey>) -> Result<()>
Sets the key to use for undoing the last split.
Sourcepub fn set_previous_comparison(&mut self, hotkey: Option<Hotkey>) -> Result<()>
pub fn set_previous_comparison(&mut self, hotkey: Option<Hotkey>) -> Result<()>
Sets the key to use for switching to the previous comparison.
Sourcepub fn set_next_comparison(&mut self, hotkey: Option<Hotkey>) -> Result<()>
pub fn set_next_comparison(&mut self, hotkey: Option<Hotkey>) -> Result<()>
Sets the key to use for switching to the next comparison.
Sourcepub fn set_undo_all_pauses(&mut self, hotkey: Option<Hotkey>) -> Result<()>
pub fn set_undo_all_pauses(&mut self, hotkey: Option<Hotkey>) -> Result<()>
Sets the key to use for removing all the pause times from the current time.
Sourcepub fn set_toggle_timing_method(&mut self, hotkey: Option<Hotkey>) -> Result<()>
pub fn set_toggle_timing_method(&mut self, hotkey: Option<Hotkey>) -> Result<()>
Sets the key to use for toggling between the Real Time and Game Time
timing methods.
Sourcepub fn deactivate(&mut self) -> Result<()>
pub fn deactivate(&mut self) -> Result<()>
Deactivates the Hotkey System. No hotkeys will go through until it gets activated again. If it’s already deactivated, nothing happens.
Sourcepub fn activate(&mut self) -> Result<()>
pub fn activate(&mut self) -> Result<()>
Activates a previously deactivated Hotkey System. If it’s already active, nothing happens.
Sourcepub const fn is_active(&self) -> bool
pub const fn is_active(&self) -> bool
Returns true if the Hotkey System is active, false otherwise.
Sourcepub const fn config(&self) -> HotkeyConfig
pub const fn config(&self) -> HotkeyConfig
Returns the hotkey configuration currently in use by the Hotkey System.
Sourcepub fn set_config(&mut self, config: HotkeyConfig) -> Result<()>
pub fn set_config(&mut self, config: HotkeyConfig) -> Result<()>
Applies a new hotkey configuration to the Hotkey System. Each hotkey is changed to the one specified in the configuration. This operation may fail if you provide a hotkey configuration where a hotkey is used for multiple operations.